@@ -2,7 +2,7 @@
 
    Copyright (c) 2008 Broad Institute / Massachusetts Institute of Technology
                  2011, 2012 Attractive Chaos <attractor@live.co.uk>
-   Copyright (C) 2009, 2013-2022 Genome Research Ltd
+   Copyright (C) 2009, 2013-2023 Genome Research Ltd
 
    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
@@ -917,7 +917,7 @@ static int load_block_from_cache(BGZF *fp, int64_t block_address)
     {
         // todo: move the error up
         hts_log_error("Could not hseek to %" PRId64, p->end_offset);
-        exit(1);
+        return -1;
     }
     return p->size;
 }
@@ -1837,7 +1837,7 @@ static int mt_destroy(mtaux_t *mt)
         free(mt->idx_cache.e);
 
     free(mt);
-    fflush(stderr);
+    /* fflush(stderr); */
 
     return ret;
 }
@@ -1959,6 +1959,11 @@ int bgzf_flush(BGZF *fp)
         return ret;
     }
 #endif
+
+    if (!fp->is_compressed) {
+        return hflush(fp->fp);
+    }
+
     while (fp->block_offset > 0) {
         int block_length;
         if ( fp->idx_build_otf )
@@ -2145,7 +2150,7 @@ int bgzf_check_EOF(BGZF *fp) {
             case CLOSE:
                 continue;
             default:
-                abort();  // Should not get to any other state
+              ;
             }
         } while (fp->mt->command != HAS_EOF_DONE);
         fp->mt->command = NONE;
@@ -2195,7 +2200,7 @@ static inline int64_t bgzf_seek_common(BGZF* fp,
                 pthread_cond_signal(&fp->mt->command_c);
                 break;
             default:
-                abort();  // Should not get to any other state
+              return -1;
             }
         } while (fp->mt->command != SEEK_DONE);
         fp->mt->command = NONE;
