@@ -176,8 +176,11 @@ unsigned char *rans_compress_O0_4x16(unsigned char *in, unsigned int in_size,
 
     switch (i=(in_size&3)) {
     case 3: RansEncPutSymbol(&rans2, &ptr, &syms[in[in_size-(i-2)]]);
+        // fall-through
     case 2: RansEncPutSymbol(&rans1, &ptr, &syms[in[in_size-(i-1)]]);
+        // fall-through
     case 1: RansEncPutSymbol(&rans0, &ptr, &syms[in[in_size-(i-0)]]);
+        // fall-through
     case 0:
         break;
     }
@@ -824,8 +827,9 @@ unsigned char *rans_uncompress_O1_4x16(unsigned char *in, unsigned int in_size,
 
 static int rans_cpu = 0xFFFF; // all
 
-#if (defined(__GNUC__) || defined(__clang__)) && defined(__x86_64__)
-// Icc and Clang both also set __GNUC__ on linux, but not on Windows.
+#if defined(__x86_64__) && \
+    defined(HAVE_DECL___CPUID_COUNT)   && HAVE_DECL___CPUID_COUNT && \
+    defined(HAVE_DECL___GET_CPUID_MAX) && HAVE_DECL___GET_CPUID_MAX
 #include <cpuid.h>
 
 #if defined(__clang__) && defined(__has_attribute)
@@ -915,9 +919,9 @@ unsigned char *(*rans_enc_func(int do_simd, int order))
 #else
     int err = pthread_once(&rans_cpu_once, htscodecs_tls_cpu_init);
     if (err != 0) {
-        fprintf(stderr, "Initialising TLS data failed: pthread_once: %s\n",
-                strerror(err));
-        fprintf(stderr, "Using scalar code only\n");
+        /* fprintf(stderr, "Initialising TLS data failed: pthread_once: %s\n", */
+        /*         strerror(err)); */
+        /* fprintf(stderr, "Using scalar code only\n"); */
     }
 #endif
 
@@ -989,9 +993,9 @@ unsigned char *(*rans_dec_func(int do_simd, int order))
 #else
     int err = pthread_once(&rans_cpu_once, htscodecs_tls_cpu_init);
     if (err != 0) {
-        fprintf(stderr, "Initialising TLS data failed: pthread_once: %s\n",
-                strerror(err));
-        fprintf(stderr, "Using scalar code only\n");
+        /* fprintf(stderr, "Initialising TLS data failed: pthread_once: %s\n", */
+        /*         strerror(err)); */
+        /* fprintf(stderr, "Using scalar code only\n"); */
     }
 #endif
 
@@ -1042,11 +1046,11 @@ static inline int have_neon(void) {
 #elif defined(__APPLE__)
     return 1;
 #elif defined(__FreeBSD__) && defined(__arm__)
-    u_long cap;
+    unsigned long cap;
     if (elf_aux_info(AT_HWCAP, &cap, sizeof cap) != 0) return 0;
     return (cap & HWCAP_NEON) != 0;
 #elif defined(__FreeBSD__) && defined(__aarch64__) && defined(HWCAP_ASIMD)
-    u_long cap;
+    unsigned long cap;
     if (elf_aux_info(AT_HWCAP, &cap, sizeof cap) != 0) return 0;
     return (cap & HWCAP_ASIMD) != 0;
 #elif defined(_WIN32)
